@@ -7,7 +7,7 @@ mod plain_text;
 pub use binary::Binary;
 pub use json::Json;
 pub use plain_text::PlainText;
-use poem::{Request, RequestBody};
+use poem::{Request, RequestBody, Result};
 
 use crate::{
     registry::{MetaSchemaRef, Registry},
@@ -15,8 +15,7 @@ use crate::{
 };
 
 /// Represents a payload type.
-#[poem::async_trait]
-pub trait Payload: Sized {
+pub trait Payload {
     /// The content type of this payload.
     const CONTENT_TYPE: &'static str;
 
@@ -26,7 +25,11 @@ pub trait Payload: Sized {
     /// Register the schema contained in this payload to the registry.
     #[allow(unused_variables)]
     fn register(registry: &mut Registry) {}
+}
 
+/// Represents a payload that can parse from HTTP request.
+#[poem::async_trait]
+pub trait ParsePayload: Sized {
     /// Parse the payload object from the HTTP request.
     async fn from_request(
         request: &Request,
@@ -34,14 +37,16 @@ pub trait Payload: Sized {
     ) -> Result<Self, ParseRequestError>;
 }
 
-#[poem::async_trait]
-impl<T: Payload> Payload for poem::Result<T> {
+impl<T: Payload> Payload for Result<T> {
     const CONTENT_TYPE: &'static str = T::CONTENT_TYPE;
 
     fn schema_ref() -> MetaSchemaRef {
         T::schema_ref()
     }
+}
 
+#[poem::async_trait]
+impl<T: ParsePayload> ParsePayload for Result<T> {
     async fn from_request(
         request: &Request,
         body: &mut RequestBody,
